onapp
    * ``auth_username`` Specify email address of the onapp account

    * ``auth_token`` Specify api key for the onapp account

    * ``auth_server`` Specify url to the onapp control panel server


.. note::
   
   The OnApp provider requires your OnApp account's email address and
   API token, which can be found on your /profile page on the Control Panel interface.
   The server is your dashboard URL, with format like https://dashboard.youronapphost.org

